Script: *ping-host.ps1*
========================

This PowerShell script pings the given host continously and shows the roundtrip times in a horizontal chart.

Parameters
----------
```powershell
PS> ./ping-host.ps1 [[-hostname] <String>] [[-timeInterval] <Int32>] [<CommonParameters>]

-hostname <String>
    Specifies the hostname or IP address of the host to ping (windows.com by default)
    
    Required?                    false
    Position?                    1
    Default value                windows.com
    Accept pipeline input?       false
    Accept wildcard characters?  false

-timeInterval <Int32>
    Specifies the time interval in milliseconds to repeat the ping (1000 by default)
    
    Required?                    false
    Position?                    2
    Default value                1000
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./ping-host.ps1



Ping Roundtrip Times to Host: windows.com
██████████████ 136ms
████████████████ 154ms
█████████████████████████ 234ms
...

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Ping a host continuously
.DESCRIPTION
	This PowerShell script pings the given host continously and shows the roundtrip times in a horizontal chart.
.PARAMETER hostname
	Specifies the hostname or IP address of the host to ping (windows.com by default)
.PARAMETER timeInterval
	Specifies the time interval in milliseconds to repeat the ping (1000 by default)
.EXAMPLE
	PS> ./ping-host.ps1
	
	Ping Roundtrip Times to Host: windows.com
	██████████████ 136ms
	████████████████ 154ms
	█████████████████████████ 234ms
	...
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$hostname = "windows.com", [int]$timeInterval = 1000)

function GetPingLatency([string]$hostname) {
	$hostsArray = $hostname.Split(",")
	$tasks = $hostsArray | foreach {
		(New-Object Net.NetworkInformation.Ping).SendPingAsync($_,1000)
	}
	[Threading.Tasks.Task]::WaitAll($tasks)
	foreach($ping in $tasks.Result) { 
        	if ($ping.Status -eq "Success") { return $ping.RoundtripTime }
	}
	return 1000
}

function WriteChartLine { param([float]$value, [float]$maxValue, [string]$text)
	$num = ($value * 110.0) / $maxValue
	while ($num -ge 1.0) {
		Write-Host -noNewLine "█"
		$num -= 1.0
	}
	if ($num -ge 0.875) {
		Write-Host -noNewLine "▉"
	} elseif ($num -ge 0.75) {
		Write-Host -noNewLine "▊"
	} elseif ($num -ge 0.625) {
		Write-Host -noNewLine "▋"
	} elseif ($num -ge 0.5) {
		Write-Host -noNewLine "▌"
	} elseif ($num -ge 0.375) {
		Write-Host -noNewLine "▍"
	} elseif ($num -ge 0.25) {
		Write-Host -noNewLine "▎"
	} elseif ($num -ge 0.125) {
		Write-Host -noNewLine "▏"
	}
	Write-Host " $text"
}

try {
	Write-Host "`nPing Roundtrip Times to Host: $($hostname)" -foregroundColor green
	do {
		[float]$latency = GetPingLatency $hostname
		WriteChartLine $latency 1000.0 "$($latency)ms"
		Start-Sleep -Milliseconds $timeInterval
	} while($true)
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 using the comment-based help of ping-host.ps1 as of 05/19/2024 10:25:24)*
